<?php
/**
 * Setup meta boxes, used in backend
 *
 */
function bpt_admin_pages_on_load() {
	// Configure tab
	add_meta_box( 'bpt-admin-metaboxes-config', __( 'Ticketing Category', 'bpt' ), 'bpt_admin_screen_ticketcategory', 'store_page_wpsc-buddypressticketing-settings');

	// Stats tab
	add_meta_box( 'bpt-admin-metaboxes-stats', __( 'Statistics', 'bpt' ), 'bpt_admin_screen_statistics', 'store_page_wpsc-buddypressticketing');
	
	//Attendees tab
	add_meta_box( 'bpt-admin-metaboxes-attendees', __( 'Attendees', 'bpt' ), 'bpt_admin_screen_attendees', 'store_page_wpsc-buddypressticketing-attendess');
	
	//Export to pdf tab
	add_meta_box( 'bpt-admin-metaboxes-pdf', __( 'Export to PDF', 'bpt' ), 'bpt_admin_screen_pdf', 'store_page_wpsc-buddypressticketing-pdf');
	///badges
	add_meta_box( 'bpt-admin-metaboxes-pdf', __( 'Create PDF Badges', 'bpt' ), 'bpt_admin_screen_badges', 'store_page_wpsc-buddypressticketing-badges');

}


/**
*
Remove the menu for event press registrations, we want to use our registration page!
*
*/
function remove_menu() {
	global $menu;

		if (class_exists('ep_admin_menus')) {
		unset($menu[31]);
		}
	}
add_action('admin_head', 'remove_menu');

/**
 * Register settings group with WordPress settings API.
 *
 */
 
function bpt_admin_register_settings() {
	register_setting( 'bpt-settings-group', 'bpt', 'bpt_admin_validate' );
}
 
/**
 * Validation function for register_setting.
 *
 * @param array $new_settings An array with changed settings
 */
function bpt_admin_validate( $new_settings ) {

	//if this is export to PDF page or badges pdf, then just output PDF, no need to return anything.
	if ( $_POST['bpt_pdf'] )
		bpt_pdf($new_settings);
		
	if($_POST['bpt_badges_pdf']){
		wpsc_display_ticket_badges($new_settings);

	}
	
	if ( is_string( $new_settings ) )
		return get_blog_option( BP_ROOT_BLOG, 'bpt' );

	if ( isset( $new_settings['ticket_category'] ) )
			$new_settings['ticket_category'] = (int) $new_settings['ticket_category'];
			
	return wp_parse_args( $new_settings, get_blog_option( BP_ROOT_BLOG, 'bpt' ) );
}


/**
 * Add "Settings" link on plugins menu 
 * 
 */
function bpt_admin_add_action_link( $actions, $plugin_file, $plugin_data ) {
	if ( 'BuddyPress Ticketing' != $plugin_data['Name'] )
		return $actions;

	$settings_link = '<a href="' . admin_url( 'admin.php?page=wpsc-buddypressticketing' ) . '">' . __( 'Settings', 'bpt' ) . '</a>';
	array_unshift( $actions, $settings_link );

	return $actions;
}
add_filter( 'plugin_action_links', 'bpt_admin_add_action_link', 10, 3 );


/**
 * Admin page for BuddyPress ticketing.
 *
 */
function bpt_admin() {
	$settings = get_blog_option( BP_ROOT_BLOG, 'bpt' );
	
	switch ( $_GET['tab'] ) {
	    case BPT_ADMIN_SETTINGS_SLUG:
	        $is_settings_tab = true;
	        break;
	    case BPT_ADMIN_ATTENDEES_SLUG:
	        $is_attendee_tab = true;
	        break;
	    case BPT_ADMIN_PDF_SLUG:
	        $is_pdf_tab = true;
	        break;
	    case BPT_ADMIN_PDF_BADGES_SLUG:
	        $is_pdf_badges_tab = true;
	        break;
	   	default:
	   		$is_statistics_tab = true;
	}	

?>
	<div id="bp-admin">
	<div id="bpt-admin-metaboxes-general" class="wrap">

		<div id="bp-admin-header">
			<h3><?php _e( 'BuddyPress', 'bpt' ) ?></h3>
			<h4><?php _e( 'WP e-Commerce Ticketing', 'bpt' ) ?></h4>
		</div>

		<div id="bp-admin-nav">
			<ol>
				<li <?php if ( $is_statistics_tab ) echo 'class="current"' ?>>
					<a href="<?php echo site_url( 'wp-admin/admin.php?page=wpsc-buddypressticketing', 'admin' ) ?>"><?php _e( 'Statistics', 'bpt' ) ?></a>
				</li>
				<li <?php if ( $is_settings_tab ) echo 'class="current"' ?>>
					<a href="<?php echo site_url( 'wp-admin/admin.php?page=wpsc-buddypressticketing&amp;tab=' . BPT_ADMIN_SETTINGS_SLUG, 'admin' )  ?>"><?php _e( 'Configure', 'bpt' ) ?></a>
				</li>
				<li <?php if ( $is_attendee_tab ) echo 'class="current"' ?>>
					<a href="<?php echo site_url( 'wp-admin/admin.php?page=wpsc-buddypressticketing&amp;tab=' . BPT_ADMIN_ATTENDEES_SLUG, 'admin' )  ?>"><?php _e( 'Attendees', 'bpt' ) ?></a>
				</li>
				<li <?php if ( $is_pdf_tab ) echo 'class="current"' ?>>
					<a href="<?php echo site_url( 'wp-admin/admin.php?page=wpsc-buddypressticketing&amp;tab=' . BPT_ADMIN_PDF_SLUG, 'admin' )  ?>"><?php _e( 'Create Attendee PDF', 'bpt' ) ?></a>
				</li>
				<li <?php if ( $is_pdf_badges_tab ) echo 'class="current"' ?>>
					<a href="<?php echo site_url( 'wp-admin/admin.php?page=wpsc-buddypressticketing&amp;tab=' . BPT_ADMIN_PDF_BADGES_SLUG, 'admin' )  ?>"><?php _e( 'Create PDF Badges', 'bpt' ) ?></a>
				</li>

			</ol>
		</div>

		<?php if ( isset( $_GET['updated'] ) ) : ?>
			<div id="message" class="updated">
				<p><?php _e( 'Your WP e-Commerce Ticketing settings have been saved.', 'bpt' ) ?></p>
			</div>
		<?php endif; ?>

		<form method="post" action="options.php" id="wpsc-buddypressticketing">
			<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ) ?>
			<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ) ?>
			<?php settings_fields( 'bpt-settings-group' ) ?>

			<div id="poststuff" class="metabox-holder">
				<div id="post-body" class="has-sidebar">
					<div id="post-body-content" class="has-sidebar-content">
						<?php
						if ( $is_settings_tab )
							do_meta_boxes( 'store_page_wpsc-buddypressticketing-settings', 'advanced', $settings );
						if ($is_attendee_tab)
							do_meta_boxes( 'store_page_wpsc-buddypressticketing-attendess', 'advanced', $settings );
						if ($is_pdf_tab)
							do_meta_boxes( 'store_page_wpsc-buddypressticketing-pdf', 'advanced', $settings );
						if ( $is_statistics_tab )
							do_meta_boxes( 'store_page_wpsc-buddypressticketing', 'advanced', $settings );
						if ( $is_pdf_badges_tab )
							do_meta_boxes( 'store_page_wpsc-buddypressticketing-badges', 'advanced', $settings );
						?>
					</div>

					<?php if ( $is_settings_tab ) : ?>
						<p><input type="submit" class="button-primary" value="<?php _e( 'Save WP e-Commerce Ticketing settings', 'bpt' ) ?>" /></p>
					<?php endif ?>
				</div>
			</div>
		</form>

	</div><!-- #bpt-admin-metaboxes-general -->
	</div><!-- #bp-admin -->
<?php
}


/**
 * Metabox for category settings
 * @param array $settings Array containing bpt settings
 */
function bpt_admin_screen_ticketcategory( $settings ) {
	$categories = bpt_wpsc_get_categories();
	$settings = maybe_unserialize($settings);
?>
	<p><label for="ticket_category"><?php _e( "Select the category to use for ticketing:", 'bpt' ) ?></label></p>

	<select name="bpt[ticket_category]">
	<?php
	foreach ( (array) $categories as $cat ) {
		$selected = '';
		if ( $settings['ticket_category'] == $cat['id'] )
			$selected = "selected='selected'";

		echo "<option value='" . $cat['id'] . "'" . $selected . ' >' . $cat['name'] . "</option>";
	}
	?>
	</select>
<?php
}


/**
 * Metabox for statistics
 * @param array $settings Array containing bpt settings
 */	
function bpt_admin_screen_statistics( $settings ) {
	global $wpdb;
	
	$url ='/wp-admin/admin.php?page=wpsc-buddypressticketing&event=';
	$product_id = bpt_select_event_dropdown($url);
	$users = bpt_get_registered_users( $product_id, true );
	
	
	$sql=  'SELECT `quantity` FROM `'.$wpdb->prefix . 'wpsc_product_list` WHERE `id` = '.$product_id[0];
	
	$ticket_total = $wpdb->get_results( $sql ) ;
	$ticket_total = $ticket_total[0]->quantity;
	$tickets_sold = bpt_get_quantities_sold($product_id);
	$remaining_tickets = ($ticket_total - $tickets_sold);

	?><h4>Stock Remaining and Stock Sold</h4><?php
	if ($ticket_total == 0)
		echo '<p> You have not entered a ticket limit for this event, to do so please edit your ticket product. </p>';
	
	echo '<p> Sold: (' .$tickets_sold .'/' . $ticket_total . ')</p>';
	echo '<p> Remaining Tickets: ' . $remaining_tickets . '</p>';

	?> <h4>Mailing List</h4> <?php
	
	$users_email = bpt_get_registered_users($product_id, false);
	foreach ($users_email as $email)
		echo $email->user_email .', ';
	
	
	$sql = 'SELECT  `data`.`value` ,  `fields`.`name` , COUNT( * ) as count 
			FROM  `' . $wpdb->prefix . 'bp_xprofile_data` `data` 
			JOIN  `' . $wpdb->prefix . 'bp_xprofile_fields` `fields` ON  `data`.`field_id` =  `fields`.`id` 
			WHERE user_id
			IN (' . implode ( ',', $users ) . ') 
			AND  `fields`.`type` 
			IN (
			"radio",  "selectbox",  "checkbox",  "multiselectbox"
			)
			GROUP BY  `data`.`value`';
	$stats = $wpdb->get_results( $sql ) ;
	if( $stats ) {
		$statistic = array();
		foreach ( (array) $stats as $stat ) {
			$statistic[$stat->name][] = array( 
				'value' => $stat->value,
				'count' => $stat->count
			);
		}
		while( current( $statistic ) ) {
			echo '<h4>' . key( $statistic ) . '</h4>';
			foreach( (array) $statistic[key($statistic)] as $stat ){
				$stat['value'] = maybe_unserialize( $stat['value'] );
				if ( is_array( $stat['value'] ) ) {
					echo implode( ', ', $stat['value'] );
				} else {
					echo $stat['value'];
				}
				echo ' <strong>(' . $stat['count'] . ')</strong><br />';
			}
			next( $statistic );
		}	
	} else {
		echo '<h2>There are no statistics for this event.</h2>';
	}
}


/**
 * Metabox for attendees list
 * @param array $settings Array containing bpt settings
 */
function bpt_admin_screen_attendees( $settings ) {
		global $wpdb;
		//this url is used in the function select drop down list
		$url ='/wp-admin/admin.php?page=wpsc-buddypressticketing&tab=attendees&event=';
		
		if ( isset( $_GET['user'] ) ) {
			$user = get_userdata( $_GET['user'] );
			$sql = 'SELECT `fields`.`name`, `data`.`value` FROM `' . $wpdb->prefix . 'bp_xprofile_data` `data` INNER JOIN `' . $wpdb->prefix . 'bp_xprofile_fields` `fields` ON `data`.`field_id` = `fields`.`id` WHERE `data`.`user_id`=' . absint( $_GET['user'] ) . ' AND `fields`.`name` != "Name"';
			$profile_fields = $wpdb->get_results( $sql );
			?>
			<h2><?php echo get_avatar( $user->user_email , '50' );?> <?php echo $user->display_name; ?></h2><?php
			foreach ( (array) $profile_fields as $field ) {
				$field->value = maybe_unserialize($field->value);
				if(is_array($field->value)){
					$field->value = implode(',', $field->value);
				}
				echo '<strong>' . $field->name . '</strong>: ' . $field->value . '<br /><br />';
			}
		} else {
			$columns = array( 
			'author' => __( 'Registered User' )
		 );
		
		$product_id = bpt_select_event_dropdown($url);
		$users=bpt_get_registered_users( $product_id );
		

		if(count($users) > 0){
			register_column_headers( 'attendees' ,$columns ); ?>
		<table class="widefat fixed" cellspacing="0">
			<thead>
				<tr class="thead">
					<?php print_column_headers( 'attendees' ); ?>
				</tr>
			</thead>		
			<tbody id="users" class="list:user user-list">
			<?php
				$style = '';
					foreach ( (array) $users as $u ) {
						if ( $style ) {
							$style = ' class="alternate"';
						} else {
							$style = '';
						}
						?>
						<tr <?php echo $style; ?>>
							<td class="username column-username">
								<?php echo get_avatar( $u->user_email , '32' ); ?> <a href="<?php echo get_admin_url( null, 'admin.php?page=wpsc-buddypressticketing&tab=attendees&user='.$u->ID, 'admin' ); ?>"><?php echo $u->display_name; ?></a>
							</td>
						</tr>
						<?php
					} 
					?>
	
			</tbody>
			<tfoot>
				<tr class="thead">
					<?php print_column_headers( 'attendees', false ); ?>
				</tr>
			</tfoot>
		</table><?php
		}else{
			echo '<h2>There are no registered attendees for this event yet.</h2>';
		}
	
	}
}


/**
 * Adds metabox to wpsc product editing page
 *
 */
function bpt_add_events_wpec_products_page() {
	add_meta_box( "bpt_wpsc_product_event", __( 'BuddyPress Tickets', 'wpsc' ), "bpt_add_events_wpec_products_pages", "wpsc" );
	do_meta_boxes( 'wpsc', 'advanced', null ); 
}
		

/**
 * Metabox function for wpsc product editing page
 * @param int $product_id Product id
 */
function bpt_add_events_wpec_products_pages( $product_id ) { 
	global $wpdb;

	
	if ( absint( $product_id ) ) {
		update_post_meta( $product_id, '_bpt_event_prod_id', $_POST['event_ticket'] );
		return true;
	}
	

	
		$sql = "SELECT `posts`.`ID`, `posts`.`post_title`, `posts`.`post_status` FROM `" . $wpdb->prefix . "posts` `posts` WHERE `posts`.`post_type` = 'ep_event'";
		$events = $wpdb->get_results( $sql ) ;
		$event_id = get_post_meta( absint( $_REQUEST['product_id'] ), '_bpt_event_prod_id', true );
		?>
		
		<P>Select the Event that this ticket product is for </p>
		<?php 
		
			foreach ( (array) $events as $event ){
				if ( $event->post_status == 'publish' ){
				?> <input type='radio' <?php if ( $event_id === $event->ID ) { echo 'checked="checked"'; } ?> value= "<?php echo $event->ID ?>" name="event_ticket" /> &nbsp; <?php echo $event->post_title . "<br />";
			
				}		
			}
				
				?>
				<p><small>NOTE: You must create the event before you create the ticket product</small></p>
<?php			
		
}

add_action( 'wpsc_edit_product', 'bpt_add_events_wpec_products_pages', 10, 1 );			

/**
 * Get ticket fields
 * Selects all the buddy press profile fields that is used for tickets
 */
function bpt_get_ticket_fields() {
	global $wpdb;
	$fields=$wpdb->get_results( 'SELECT `fields`.`name`, `fields`.`id` FROM `' . $wpdb->prefix . 'bp_xprofile_fields` `fields` WHERE `fields`.`parent_id`=0' );

	return $fields;

}
/**
 * Export PDF metabox
 * @param array $new_settings An array with changed settings
 */
function bpt_admin_screen_pdf( $settings, $product_id) {
	global $wpdb;
	$url='/wp-admin/admin.php?page=wpsc-buddypressticketing&tab=pdf&event=';
	$product_id = bpt_select_event_dropdown($url); ?>
	<form name="bpt_pdf" method="post" enctype="multipart/form-data"  action="">

 	
	<?php $fields = bpt_get_ticket_fields();  
		foreach ( (array) $fields as $field ) {
		$checked='';
		if ( @in_array( $field->id, $settings['fields'] ) )
			$checked='checked="checked"';
	?>
	<br /><input type="checkbox" name="bpt[fields][]" value="<?php echo $field->id; ?>" <?php echo $checked; ?>/> <?php echo $field->name;
	
	} ?>

	<input type="hidden" name="bpt_pdf" value="true" />
	<p><input type="submit" class="button-primary" value="<?php _e( 'Export as PDF', 'bpt' ); ?>" /></p>
	 </form>
	 <?php
}

/**
 * Badges PDF metabox
 * @param array $new_settings An array with changed settings
 */
function bpt_admin_screen_badges( $settings, $product_id ) {
	global $wpdb;
	$url='/wp-admin/admin.php?page=wpsc-buddypressticketing&tab=badges&event='; ?>
	
	<div class="float_left" id="badges_options">
	<?php $product_id = bpt_select_event_dropdown($url); ?>
		<br /><p><?php _e('Select the attendee data you would like to display on your ticket / badge, the template position number relates to the template. If you don\'t want to use all the template areas then leave them blank' , 'bpt');?></p>

<table> <form name="bpt_badges_pdf" method="post" enctype="multipart/form-data"  action="">
	<tr>
		<td><label for 'bpt_badges_pdf'>Upload your logo:</label></td>
		<td><input type="file" name="bpt_badges_logo"></td>
	</tr>
	<tr>
		<td>Show Gravitar</td>
		<td class='badges_pdf'>Yes<input type='radio' checked = 'checked' name='badges_gravatar' value='1' >No<input type='radio' name='badges_gravatar' value='0' ></td>
	</tr>
	
	<?php
	$extra_fields = array(
	   array(name => "Twitter Id", id => 'badges_twitter',),
	   array(name => "Site Link", id => 'badges_site',),
	   array(name => "Email Address", id => 'badges_email',)
	);
	
	//exit('<pre>'.print_r($extra_fields,true).'</pre>');
	
	foreach ((array)$extra_fields as $field ) {
	?>	
		<tr>
			<?php echo '<td>'.$field[name] . '</td>';
			$value= $field[id];
	for($i=1; $i < 8; $i++){
		if($i == 1)
			echo'<td class="badges_pdf">';
			
		if ($field['id'] == 'badges_twitter' && $i == 3)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
			
		elseif ($field['id'] == 'badges_email' && $i == 4)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
			
		elseif ($field['id'] == 'badges_site' && $i == 5)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
		else
			echo "$i<input type='radio' name='bpt[fields][".$i."]' value=' ".$value."' > ";
		if($i == 7)
			echo'</td></div>';
			}
			
	?> 	</tr><?php
	 } 
	 
	 $fields= bpt_get_ticket_fields();
	 
	foreach ((array) $fields as $field ) {
		$selected='';?>
			<tr>
				<?php echo '<td>'.$field->name . '</td>';
				$value= $field->id;
				create_badges_radio_button($value, $settings, $field);
		?> 	</tr>
		<?php } 

		
		?>
			
	<input type="hidden" name="bpt_badges_pdf" value="true" />
	<p><input type="submit" class="button-primary" value="<?php _e( 'Export badges as PDF', 'bpt' ); ?>" /></p>
	</form></table></div>

	<div class="float_left_img">
	<p><strong>Badges Template</strong></p>
<?php 

$template_url = plugins_url('templates/bpt/badges/badges_template.jpg', __FILE__);
echo "<img src='" . $template_url."' alt='badges_template'/>" ; 
?> </div>


<div class="float_left_img">
 <p><strong>Example using the default settings</strong></p> 
<?php
$template1_url = plugins_url('templates/bpt/badges/wordcamp-ticket-badge.jpg', __FILE__);
echo "<img src='" . $template1_url."' alt='badges_template'/>" ; 
?> </div>
<div class='clear'> </div>
	<?php }

function create_badges_radio_button($value, $settings,$field) {

	for($i=1; $i < 8; $i++){
		if($i == 1)
			echo'<td class="badges_pdf">';
			
			
//recommended layout for pdf badges
		
		if ($field->name == 'First name' && $i == 1)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
			
		elseif ($field->name == 'Last name' && $i == 2)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
			
		elseif ($field->name == 'How would you describe yourself' && $i == 7)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
		
		elseif ($field->name == 'How long have you been using WordPress' && $i == 6)
			echo "$i<input checked = 'checked' type='radio' name='bpt[fields][".$i."]' value='".$value."'> ";
		else
			echo "$i<input type='radio' name='bpt[fields][".$i."]' value=' ".$value."' > ";

		if($i == 7)
			echo'</td></div>';
			}
}

/**
 * Event selection dropdown
 * @return array Array of product IDs associated with event 
 * $url is the location this is used because atendees and stats page have different urls but use same function. More tabs etc can now be added and used
 */
function bpt_select_event_dropdown($url) {
	global $wpdb;
	
	$sql = "SELECT `id`, `post_title` FROM " . $wpdb->posts . " WHERE `post_type` = 'ep_event' AND post_status != 'auto-draft'";
	$events = $wpdb->get_results( $sql ) ; 

?>
	<label for="events">Select an Event:</label>
	<select name="events_dropdown" style="width:200px" onchange="location.href='<?php bloginfo( 'url' );?><?php echo $url;?>'+document.getElementById('events_dropdown').value;" id="events_dropdown"><?php
	foreach( (array) $events as $event ) {
		$selected='';
		if( $event->id == $_GET['event'] )
			$selected="selected='selected'";
		echo '<option ' . $selected . ' value="' . $event->id . '">' . $event->post_title . '</option>';
	}
	?>
	</select>
	<?php

	if ( isset ( $_GET['event'] ) ) {
	 	$event = absint( $_GET['event'] );
	} else {
		$event = $wpdb->get_var( "SELECT `id` FROM " . $wpdb->prefix . "posts WHERE `post_type` = 'ep_event' AND `post_status` != 'draft' LIMIT 1" );
	}	 
	
	$product_id = $wpdb->get_col( 'SELECT post_id FROM ' . $wpdb->postmeta . ' WHERE meta_key = "_bpt_event_prod_id" AND meta_value = ' . $event );
	
	return $product_id;
}


/**
 * Output PDF
 *
 */
function bpt_pdf($settings) {
//exit('<pre>'.print_r($settings,true).'</pre>');

	$pdf=new PDF();
	$pdf->AliasNbPages();
	
	//load data
	$pdf->LoadData( $settings);
	
	$pdf->SetFont( 'Arial', '', 8);
	$pdf->AddPage(L);
	$pdf->PrintTable();

	$pdf->Output();
	exit();
}

/**
 * Output Badges PDF Needs finishing
 *
 */

function wpsc_display_ticket_badges($settings){
	global $wpdb;

@ini_set('log_errors','on');
@ini_set('display_errors','on');

//require_once(WPSC_FILE_PATH."/wpsc-includes/fpdf/mc_table.php");
require_once('bpt-functions.php');

@ini_set( 'memory_limit', '128M' );
@ini_set( 'max_input_time', '240' );
// Set up the new PDF object
$pdf = new PDF( 'L', 'in', 'Legal' );

$attendees = $pdf->LoadBadgesData($settings);
//exit('<pre> broke?'. print_r($attendees,true).'</pre>');
// Remove page margins.
$pdf->SetMargins(0, 0);
$pdf->SetFont('helvetica','',10);
// Disable auto page breaks.
$pdf->SetAutoPageBreak(0);
//$this->LoadBadgesData($settings)
//require_once( 'attendees_badges.php' );
// Set up badge counter
$counter = 1;
//exit('Attendees'.count($attendees).'<pre>'.print_r($attendees, true).'</pre>');
// Loop through each attendee and create a badge for them
//echo('<pre>'.print_r($attendees,true).'</pre>WHAT THE DUs?');




for ( $i = 0; $i < count($attendees); $i++ ) {
//for ( $i = 0; $i < 2; $i++ ) {
		
		// Set the text color to black.
		$pdf->SetTextColor(223,125,80);

		// Grab the template file that will be used for the badge page layout
		require('templates/sf2010.php');

		// Download and store the gravatar for use, FPDF does not support gravatar formatted image links
		$grav_file_raw = WP_CONTENT_DIR.'/plugins/'.WPSC_TICKETS_FOLDER.'/images/temp/' . $attendees[$i][0] . '-' . rand();
		$grav_url = 'http://www.gravatar.com/avatar/' . md5($attendees[$i][7]) . '?s=512&default=http%3A%2F%2F2010.sf.wordcamp.org%2Fblank.jpg';
	//	exit('Data from Gravatar '.$grav_url);
		$grav_data = get_file_by_curl( $grav_url, $grav_file_raw );

		// Check if the image is a png, if it is, convert it, otherwise add a JPG extension to the raw filename
		if ( !$grav_file = pngtojpg($grav_file_raw) ) {
			$grav_file_extension = get_image_extension($grav_file_raw);
			$grav_file = $grav_file_raw . $grav_file_extension;
			rename( $grav_file_raw, $grav_file );
		}
		// Add the background image for the badge to the page
		$back_path = WP_CONTENT_DIR.'/plugins/'.WPSC_TICKETS_FOLDER.'/images/badgelogo.jpg';
		$pdf->image($back_path, $background_x, $background_y, 2.8, 1.23);

		//set all images to the man.jpg for testing

		$pdf->image($grav_file, $avatar_x, $avatar_y, 0.6, 0.6);
		$pdf->SetDrawColor(187,187,187);
		$pdf->Rect($avatar_x - 0.02, $avatar_y - 0.02, 0.64, 0.64);

		// Set the co-ordinates, font, and text for the first name
		$pdf->SetXY($text_x, $text_y);
		$pdf->SetFont('helvetica','b',28);
		$pdf->MultiCell(0, 0,ucwords(stripslashes($attendees[$i][0])),0,'L');

		// Set the co-ordinates, font, and text for the last name
		$pdf->SetXY($text_x, $text_y + 0.35);
		$pdf->SetFont('helvetica','',18);
		$pdf->SetTextColor(112,205,223);
		$pdf->MultiCell(0, 0,stripslashes(ucwords($attendees[$i][1])),0,'L');

		$pdf->SetXY($infotext_x, $infotext_y);
		$pdf->SetFont('helvetica','',10);
		$pdf->SetTextColor(99,100,102);

	
		$pdf->SetFont('helvetica','b',11);
		$pdf->MultiCell( 2.4, 0.21, stripslashes($attendees[$i][2]), 0, 'L' );
		$infotext_y += 0.23;
		

		
		$pdf->SetXY($infotext_x, $infotext_y);
		$pdf->SetFont('helvetica','',10);
		$pdf->MultiCell( 2.4, 0.21, stripslashes($attendees[$i][3]), 0, 'L' );
		$infotext_y += 0.23;
			
		$pdf->SetXY($infotext_x, $infotext_y);
		$pdf->SetFont('helvetica','b',11);
		$pdf->MultiCell( 2.4, 0.21, stripslashes($attendees[$i][4]), 0, 'L' );
				
		$pdf->SetXY($years_x + 0.21, $years_y);
		$pdf->SetFont('helvetica','',8);
		$pdf->MultiCell( 2.4, 0.21, stripslashes($attendees[$i][5]), 0, 'R' );
			
		// Grey: 186, 188, 191
		// Automattic: 6, 66, 108

		$pdf->SetFillColor( 95, 188, 208 );
		$pdf->Rect( $typebox_x, $typebox_y, 3, 0.5, 'F' );

		$pdf->SetTextColor(255, 255, 255);
		$pdf->SetXY($typebox_x, $typebox_y);
		$pdf->SetFont('helvetica','b', 12);
		$pdf->MultiCell( 3, 0.5, strtoupper($attendees[$i][6]), 0, 'C' );


		$pdf->SetDrawColor(187,187,187);
		$counter++;
}

//exit('<pre>'.print_r($pdf,1).'</pre>');
// Output the PDF file to the browser
$pdf->Output();
exit();
}


/**
 * Create counter for tickets sold..
 *
 */
function bpt_get_total_quanity($product_id){
	global $wpdb;
	$sql = 'SELECT SUM(`'.WPSC_TABLE_CART_CONTENTS.'`.`quantity`) FROM `'.WPSC_TABLE_CART_CONTENTS.'` LEFT JOIN `'.WPSC_TABLE_PURCHASE_LOGS.'` ON `'.WPSC_TABLE_CART_CONTENTS.'`.`purchaseid` = `'.WPSC_TABLE_PURCHASE_LOGS.'`.`id` WHERE `'.WPSC_TABLE_PURCHASE_LOGS.'`.`processed` >1 AND `'.WPSC_TABLE_PURCHASE_LOGS.'`.`processed` < 5  AND `'.WPSC_TABLE_CART_CONTENTS.'`.`prodid`='.$id;
	$num = $wpdb->get_var($sql);
	if($num != null){
		return $num;
	}else{
		return 0;
	}
}

function bpt_get_quantities_sold($product_id){
	
	$users = bpt_get_registered_users( $product_id, true );
	return count($users);
	}
	
?>